ExternalLibrary class

This is only intended to be used by automatically generated code, instead of developers.

Constructors

ExternalLibrary.open(String path, {String debugInfo = ''})
The code is used only internally and is not a public API. The comment exists mainly to satisfy the linter.
factory
ExternalLibrary.process({required bool iKnowHowToUseIt, String debugInfo = ''})
Firstly, usually you do NOT need to use this function at all. Under all platforms, Flutter officially suggests open() (see https://github.com/flutter/flutter/blob/8b6277e63868c2029f1e2327879b7899be44fbe2/packages/flutter_tools/templates/plugin_ffi/lib/projectName.dart.tmpl#L47-L58), and flutter_rust_bridge's template also uses the open().
factory

Properties

debugInfo → String
finalinherited
ffiDynamicLibrary → DynamicLibrary
This is only intended to be used by automatically generated code, instead of developers.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited