AllowInteropFunctionWrapper class

The code is used only internally and is not a public API. The comment exists mainly to satisfy the linter.

Constructors

AllowInteropFunctionWrapper(Function inner)
The code is used only internally and is not a public API. The comment exists mainly to satisfy the linter.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inner → Function
The code is used only internally and is not a public API. The comment exists mainly to satisfy the linter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited