ExternalLibrary constructor
This is only intended to be used by automatically generated code, instead of developers.
Implementation
const ExternalLibrary({
required super.debugInfo,
this.wasmBindgenName = 'wasm_bindgen',
});
This is only intended to be used by automatically generated code, instead of developers.
const ExternalLibrary({
required super.debugInfo,
this.wasmBindgenName = 'wasm_bindgen',
});