wasmBindgenName property
This is only intended to be used by automatically generated code, instead of developers.
Implementation
final String wasmBindgenName;
This is only intended to be used by automatically generated code, instead of developers.
final String wasmBindgenName;