RustOpaqueInterface class abstract

This is only intended to be used by automatically generated code, instead of developers.

Implementers

Constructors

RustOpaqueInterface()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether the underlying Arc is disposed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose the underlying Arc.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited