WireSyncRust2DartDco typedef
WireSyncRust2DartDco = Object?
This is only intended to be used by automatically generated code, instead of developers.
Implementation
typedef WireSyncRust2DartDco = Object?;
This is only intended to be used by automatically generated code, instead of developers.
typedef WireSyncRust2DartDco = Object?;