ExternalLibraryLoaderConfig class
Arguments of loadExternalLibrary
Constructors
- ExternalLibraryLoaderConfig({required String stem, required String? ioDirectory, required String? webPrefix, String wasmBindgenName = 'wasm_bindgen'})
-
Arguments of
loadExternalLibraryconst
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ioDirectory → String?
-
In io (native), the directory that may find the dynamic library
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stem → String
-
The file stem
final
- wasmBindgenName → String
-
The name of the wasm_bindgen module.
final
- webPrefix → String?
-
In Web, the prefix path for the wasm
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited